@@ -1,9 +1,13 @@
 #!/usr/bin/env bash
+changed_golang_packages=$(git status --porcelain | awk '{print $2}' | grep '\.go$' | xargs dirname | sort | uniq)
 
 if  [[ -x "$(command -v golangci-lint)" ]]; then
   echo "golangci-lint executable found."
-  echo "Run golangci-lint"
-  $(command -v golangci-lint) run ./agent/... ./core/... ./common/...
+  echo "Running golangci-lint on changed files"
+  for package_dir in $changed_golang_packages
+  do
+    $(command -v golangci-lint) run "$package_dir/..."
+  done
 else
   bold=$(tput bold)
   normal=$(tput sgr0)
