@@ -37,7 +37,7 @@ import (
 	"github.com/aws/amazon-ssm-agent/agent/jsonutil"
 	"github.com/aws/amazon-ssm-agent/agent/log"
 	"github.com/aws/amazon-ssm-agent/agent/times"
-	"github.com/aws/amazon-ssm-agent/common/identity"
+	"github.com/aws/amazon-ssm-agent/common/identity/identity"
 	"github.com/carlescere/scheduler"
 )
 
@@ -83,8 +83,9 @@ func NewAssociationProcessor(context context.T) *Processor {
 	uploader := complianceUploader.NewComplianceUploader(context)
 
 	//TODO Rename everything to service and move package to framework
-	//association has no cancel worker
-	proc := processor.NewEngineProcessor(assocContext, documentWorkersLimit, documentWorkersLimit, []contracts.DocumentType{contracts.Association})
+	startWorker := processor.NewWorkerProcessorSpec(assocContext, documentWorkersLimit, contracts.Association, 0)
+	terminateWorker := processor.NewWorkerProcessorSpec(assocContext, documentWorkersLimit, "", 0) //association has no cancel worker
+	proc := processor.NewEngineProcessor(assocContext, startWorker, terminateWorker)
 	return &Processor{
 		context:            assocContext,
 		assocSvc:           assocSvc,
@@ -98,7 +99,7 @@ func NewAssociationProcessor(context context.T) *Processor {
 func (p *Processor) ModuleExecute() {
 	log := p.context.Log()
 	associationFrequenceMinutes := p.context.AppConfig().Ssm.AssociationFrequencyMinutes
-	log.Info("Starting association polling")
+	log.Debug("Starting association polling")
 	log.Debugf("Association polling frequency is %v", associationFrequenceMinutes)
 	var job *scheduler.Job
 	var err error
@@ -111,14 +112,14 @@ func (p *Processor) ModuleExecute() {
 	p.InitializeAssociationProcessor()
 	p.SetPollJob(job)
 }
-func (p *Processor) ModuleRequestStop(stopType contracts.StopType) (err error) {
+func (p *Processor) ModuleStop() (err error) {
 	assocScheduler.Stop(p.pollJob)
 	signal.Stop()
-	p.proc.Stop(stopType)
+	p.proc.Stop()
 	return nil
 }
 
-// StartAssociationWorker starts worker to process scheduled association
+// InitializeAssociationProcessor starts worker to process scheduled association
 func (p *Processor) InitializeAssociationProcessor() {
 	log := p.context.Log()
 	if resChan, err := p.proc.Start(); err != nil {
@@ -128,7 +129,7 @@ func (p *Processor) InitializeAssociationProcessor() {
 		p.resChan = resChan
 	}
 
-	log.Info("Launching response handler")
+	log.Debug("Launching response handler")
 	go p.listenToResponses()
 
 	if err := p.proc.InitialProcessing(false); err != nil {
@@ -136,9 +137,9 @@ func (p *Processor) InitializeAssociationProcessor() {
 		return
 	}
 
-	log.Info("Initializing association scheduling service")
+	log.Debug("Initializing association scheduling service")
 	signal.InitializeAssociationSignalService(log, p.runScheduledAssociation)
-	log.Info("Association scheduling service initialized")
+	log.Debug("Association scheduling service initialized")
 }
 
 // SetPollJob represents setter for PollJob
@@ -451,7 +452,7 @@ func (r *Processor) pluginExecutionReport(
 	outputs map[string]*contracts.PluginResult,
 	totalNumberOfPlugins int) {
 
-	_, _, runtimeStatuses := contracts.DocumentResultAggregator(log, pluginID, outputs)
+	_, _, _, runtimeStatuses := contracts.DocumentResultAggregator(log, pluginID, outputs)
 	outputContent, err := jsonutil.Marshal(runtimeStatuses)
 	if err != nil {
 		log.Error("could not marshal plugin outputs! ", err)
@@ -496,7 +497,7 @@ func (r *Processor) associationExecutionReport(
 	errorCode string,
 	associationStatus string) {
 
-	_, _, runtimeStatuses := contracts.DocumentResultAggregator(log, "", outputs)
+	_, _, _, runtimeStatuses := contracts.DocumentResultAggregator(log, "", outputs)
 	runtimeStatusesContent, err := jsonutil.Marshal(runtimeStatuses)
 	if err != nil {
 		log.Error("could not marshal plugin outputs ", err)
@@ -595,9 +596,7 @@ func (r *Processor) listenToResponses() {
 			//TODO move this part to service
 			schedulemanager.UpdateNextScheduledDate(log, res.AssociationID)
 			signal.ExecuteAssociation(log)
-
 		}
-
 	}
 }
 
@@ -656,8 +655,8 @@ func filterByStatus(runtimeStatuses map[string]*contracts.PluginRuntimeStatus, p
 	return result
 }
 
-//This operation is locked by runScheduledAssociation
-//lazy update, update only when the document is ready to run, update will validate and invalidate current attached association
+// This operation is locked by runScheduledAssociation
+// lazy update, update only when the document is ready to run, update will validate and invalidate current attached association
 func updatePluginAssociationInstances(associationID string, docState *contracts.DocumentState) {
 	currentPluginAssociations := getPluginAssociationInstances()
 	for i := 0; i < len(docState.InstancePluginsInformation); i++ {
