@@ -271,7 +271,7 @@ func s3Download(context context.T, amazonS3URL s3util.AmazonS3URL, destFile stri
 		params.ExpectedBucketOwner = aws.String(expectedBucketOwner)
 	}
 
-	if fileutil.Exists(destFile) == true && fileutil.Exists(eTagFile) == true {
+	if fileutil.Exists(destFile) && fileutil.Exists(eTagFile) {
 		var existingETag string
 		existingETag, err = fileutil.ReadAllText(eTagFile)
 		if err != nil {
@@ -404,7 +404,7 @@ func Download(context context.T, input DownloadInput) (output DownloadOutput, er
 		err = nil
 	}
 
-	if isLocalFile == true {
+	if isLocalFile {
 		err = fmt.Errorf("source is a local file, skipping download. %v", input.SourceURL)
 		output.LocalFilePath = input.SourceURL
 		output.IsUpdated = false
@@ -435,7 +435,7 @@ func Download(context context.T, input DownloadInput) (output DownloadOutput, er
 		}
 
 		isLocalFile, err = fileutil.LocalFileExist(output.LocalFilePath)
-		if isLocalFile == true {
+		if isLocalFile {
 			output.IsHashMatched, err = VerifyHash(log, input, output)
 		}
 	}
@@ -443,6 +443,61 @@ func Download(context context.T, input DownloadInput) (output DownloadOutput, er
 	return
 }
 
+func setupDestinationDirectory(context context.T, input DownloadInput) (localFilePath string, err error) {
+	log := context.Log()
+
+	fileURL, err := url.Parse(input.SourceURL)
+	if err != nil {
+		log.Errorf("url parsing failed. %v", err)
+		return
+	}
+
+	// default destination directory is app config download root
+	destinationDir := input.DestinationDirectory
+	if destinationDir == "" {
+		destinationDir = appconfig.DownloadRoot
+	}
+
+	err = fileutil.MakeDirs(destinationDir)
+	if err != nil {
+		err = fmt.Errorf("failed to create directory=%v, err=%v", destinationDir, err)
+	}
+	urlHash := sha1.Sum([]byte(fileURL.String()))
+	localFilePath = filepath.Join(destinationDir, fmt.Sprintf("%x", urlHash))
+	return
+}
+
+func DownloadUsingHttp(context context.T, input DownloadInput) (*DownloadOutput, error) {
+	log := context.Log()
+	output := DownloadOutput{}
+	var err error
+
+	output.LocalFilePath, err = setupDestinationDirectory(context, input)
+	if err != nil {
+		return nil, err
+	}
+
+	output, err = httpDownload(context, input.SourceURL, output.LocalFilePath, "")
+	if err != nil {
+		err = fmt.Errorf("Download failed due to %v", err)
+		return nil, err
+	}
+
+	doesLocalFileExist, err := fileutil.LocalFileExist(output.LocalFilePath)
+	if err != nil {
+		err = fmt.Errorf("could not read output file %v", err)
+		return nil, err
+	}
+	if doesLocalFileExist {
+		output.IsHashMatched, err = VerifyHash(log, input, output)
+		if err != nil {
+			err = fmt.Errorf("could not verify hash -  %v", err)
+			return nil, err
+		}
+	}
+	return &output, nil
+}
+
 // VerifyHash verifies the hash of the url file as per specified hash algorithm type and its value
 func VerifyHash(log log.T, input DownloadInput, output DownloadOutput) (bool, error) {
 	hasMatchingHash := false
