@@ -11,6 +11,7 @@
 // either express or implied. See the License for the specific language governing
 // permissions and limitations under the License.
 
+//go:build freebsd || linux || netbsd || openbsd
 // +build freebsd linux netbsd openbsd
 
 package network
@@ -26,14 +27,8 @@ func getSystemCertPool() (*x509.CertPool, error) {
 	return x509.SystemCertPool()
 }
 
-func getCustomCertificate() ([]byte, error) {
-
-	config, err := appconfig.Config(false)
-	if err != nil {
-		return nil, err
-	}
-
-	if !config.Agent.ContainerMode {
+func getCustomCertificate(appConfig appconfig.SsmagentConfig) ([]byte, error) {
+	if !appConfig.Agent.ContainerMode {
 		// Custom certificate only supported in container mode
 		return nil, nil
 	}
