@@ -40,11 +40,3 @@ func TestFullyQualifiedDomainName(t *testing.T) {
 	t.Logf("fqdn/hostname is %v", fullyQualifiedDomainName(log))
 	assert.True(t, true, "expected no error trying to retrieve the fqdn/hostname value")
 }
-
-func TestGetPlatformType(t *testing.T) {
-	var log = logger.NewMockLog()
-	t.Log("get platform type")
-	data, err := PlatformType(log)
-	t.Logf("platform type is %v ", data)
-	assert.NoError(t, err, "get platform type should not result in err")
-}
