@@ -91,10 +91,6 @@ const PlatformWindows = "windows"
 // PlatformDarwin uses Ohai identifier for darwin platform
 const PlatformDarwin = "mac_os_x"
 
-// OperatingSystemSKUs to denote Windows Nano installations
-const SKUProductDatacenterNanoServer uint32 = 143
-const SKUProductStandardNanoServer uint32 = 144
-
 // Init marks a init system used by the Operating Sysstem
 
 // InitSystemd uses identifier for systemd init system
