@@ -26,6 +26,8 @@ import (
 	"github.com/aws/amazon-ssm-agent/agent/appconfig"
 	"github.com/aws/amazon-ssm-agent/agent/context"
 	"github.com/aws/amazon-ssm-agent/agent/log"
+	contextmocks "github.com/aws/amazon-ssm-agent/agent/mocks/context"
+	logmocks "github.com/aws/amazon-ssm-agent/agent/mocks/log"
 	"github.com/aws/amazon-ssm-agent/agent/sdkutil/retryer"
 	identityMocks "github.com/aws/amazon-ssm-agent/common/identity/mocks"
 	"github.com/aws/aws-sdk-go/aws"
@@ -48,9 +50,15 @@ func (m *MockedHttpProvider) Head(url string) (*http.Response, error) {
 	return args.Get(0).(*http.Response), args.Error(1)
 }
 
-func setS3Endpoint(region, endpoint string) {
-	getS3Endpoint = func(context context.T, region string) string {
-		return endpoint
+func setBucketRegionFromSignedHeadBucketRequest(bucketRegion string) {
+	getBucketRegionFromSignedHeadBucketRequestFunc = func(context context.T, region, regionalEndpoint, bucketName string) string {
+		return bucketRegion
+	}
+}
+
+func setS3Endpoint(region, endpoint string, err error) {
+	getS3Endpoint = func(context context.T, region string) (string, error) {
+		return endpoint, err
 	}
 }
 
@@ -60,8 +68,81 @@ func setS3FallbackEndpoint(region, endpoint string) {
 	}
 }
 
+func TestBucketRegion_WithHeadBucketRequestSuccessful(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("us-east-1")
+	setS3Endpoint("us-east-1", "", fmt.Errorf("invalid region"))
+
+	resp := &http.Response{
+		StatusCode: 200,
+		Header: http.Header{
+			bucketRegionHeader: []string{"us-east-1"},
+		},
+	}
+	var err error = nil
+	httpProvider := &MockedHttpProvider{}
+	httpProvider.On("Head", "https://bucket-1.s3.amazonaws.com").Return(resp, err)
+	actual := getBucketRegion(contextmocks.NewMockDefault(), "us-east-1", "bucket-1", httpProvider)
+	expected := "us-east-1"
+	assert.Equal(t, expected, actual)
+}
+
+func TestGetBucketRegion_NoError_InvalidS3Endpoint_ReturnsRegionFromFallback(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
+	setS3Endpoint("us-east-1", "", fmt.Errorf("invalid region"))
+	setS3FallbackEndpoint("us-east-1", "s3.amazonaws.com")
+
+	resp := &http.Response{
+		StatusCode: 200,
+		Header: http.Header{
+			bucketRegionHeader: []string{"us-east-1"},
+		},
+	}
+	var err error = nil
+	httpProvider := &MockedHttpProvider{}
+	httpProvider.On("Head", "https://bucket-1.s3.amazonaws.com").Return(resp, err)
+	actual := getBucketRegion(contextmocks.NewMockDefault(), "us-east-1", "bucket-1", httpProvider)
+	expected := "us-east-1"
+	assert.Equal(t, expected, actual)
+}
+
+func TestGetBucketRegion_NoError_InvalidFallbackS3Endpoint_ReturnsRegionFroms3(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
+	setS3Endpoint("us-east-1", "s3.us-east-1.amazonaws.com", nil)
+	setS3FallbackEndpoint("us-east-1", "")
+	resp := &http.Response{
+		StatusCode: 200,
+		Header: http.Header{
+			bucketRegionHeader: []string{"us-east-1"},
+		},
+	}
+	var err error = nil
+	httpProvider := &MockedHttpProvider{}
+	httpProvider.On("Head", "https://bucket-1.s3.us-east-1.amazonaws.com").Return(resp, err)
+	actual := getBucketRegion(contextmocks.NewMockDefault(), "us-east-1", "bucket-1", httpProvider)
+	expected := "us-east-1"
+	assert.Equal(t, expected, actual)
+}
+
+func TestGetBucketRegion_NoError_InvalidS3Endpoint_Error(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
+	setS3Endpoint("us-east-1", "", fmt.Errorf("invalid region"))
+	setS3FallbackEndpoint("us-east-1", "")
+	resp := &http.Response{
+		StatusCode: 200,
+		Header: http.Header{
+			bucketRegionHeader: []string{"us-east-1"},
+		},
+	}
+	var err error = nil
+	httpProvider := &MockedHttpProvider{}
+	httpProvider.On("Head", "https://bucket-1.s3.us-east-1.amazonaws.com").Return(resp, err)
+	actual := getBucketRegion(contextmocks.NewMockDefault(), "us-east-1", "bucket-1", httpProvider)
+	assert.Equal(t, "", actual)
+}
+
 func TestGetBucketRegion_NoError_NoRegionInResponse_ReturnsEmptyString(t *testing.T) {
-	setS3Endpoint("us-east-1", "s3.us-east-1.amazonaws.com")
+	setBucketRegionFromSignedHeadBucketRequest("")
+	setS3Endpoint("us-east-1", "s3.us-east-1.amazonaws.com", nil)
 	setS3FallbackEndpoint("us-east-1", "s3.amazonaws.com")
 	resp := &http.Response{
 		StatusCode: 401,
@@ -70,12 +151,13 @@ func TestGetBucketRegion_NoError_NoRegionInResponse_ReturnsEmptyString(t *testin
 	httpProvider := &MockedHttpProvider{}
 	httpProvider.On("Head", "https://bucket-1.s3.us-east-1.amazonaws.com").Return(resp, err)
 	httpProvider.On("Head", "https://bucket-1.s3.amazonaws.com").Return(resp, err)
-	actual := getBucketRegion(context.NewMockDefault(), "us-east-1", "bucket-1", httpProvider)
+	actual := getBucketRegion(contextmocks.NewMockDefault(), "us-east-1", "bucket-1", httpProvider)
 	assert.Equal(t, "", actual)
 }
 
 func TestGetBucketRegion_NoError_RegionInResponse_ReturnsRegion(t *testing.T) {
-	setS3Endpoint("us-east-1", "s3.us-east-1.amazonaws.com")
+	setBucketRegionFromSignedHeadBucketRequest("")
+	setS3Endpoint("us-east-1", "s3.us-east-1.amazonaws.com", nil)
 	setS3FallbackEndpoint("us-east-1", "s3.amazonaws.com")
 	resp := &http.Response{
 		StatusCode: 301,
@@ -86,12 +168,13 @@ func TestGetBucketRegion_NoError_RegionInResponse_ReturnsRegion(t *testing.T) {
 	var err error = nil
 	httpProvider := &MockedHttpProvider{}
 	httpProvider.On("Head", "https://bucket-1.s3.us-east-1.amazonaws.com").Return(resp, err)
-	actual := getBucketRegion(context.NewMockDefault(), "us-east-1", "bucket-1", httpProvider)
+	actual := getBucketRegion(contextmocks.NewMockDefault(), "us-east-1", "bucket-1", httpProvider)
 	assert.Equal(t, "eu-west-1", actual)
 }
 
 func TestGetBucketRegion_AllUrlsFail_ReturnsEmptyString(t *testing.T) {
-	setS3Endpoint("us-east-1", "s3.us-east-1.amazonaws.com")
+	setBucketRegionFromSignedHeadBucketRequest("")
+	setS3Endpoint("us-east-1", "s3.us-east-1.amazonaws.com", nil)
 	setS3FallbackEndpoint("us-east-1", "s3.amazonaws.com")
 	var resp *http.Response = nil
 	err := fmt.Errorf("failed")
@@ -100,14 +183,15 @@ func TestGetBucketRegion_AllUrlsFail_ReturnsEmptyString(t *testing.T) {
 	httpProvider.On("Head", "https://bucket-1.s3.amazonaws.com").Return(resp, err)
 	httpProvider.On("Head", "http://bucket-1.s3.us-east-1.amazonaws.com").Return(resp, err)
 	httpProvider.On("Head", "http://bucket-1.s3.amazonaws.com").Return(resp, err)
-	actual := getBucketRegion(context.NewMockDefault(), "us-east-1", "bucket-1", httpProvider)
+	actual := getBucketRegion(contextmocks.NewMockDefault(), "us-east-1", "bucket-1", httpProvider)
 	assert.Equal(t, "", actual)
 	httpProvider.AssertExpectations(t)
 }
 
 func TestGetS3CrossRegionCapableSession_regionFromHead_noConfigOverrides(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	setupMocksForGetS3CrossRegionCapableSession("us-east-1", "bucket-1", "eu-west-1")
-	sess, err := GetS3CrossRegionCapableSession(context.NewMockDefault(), "bucket-1")
+	sess, err := GetS3CrossRegionCapableSession(contextmocks.NewMockDefault(), "bucket-1")
 	assert.NotNil(t, sess)
 	assert.Equal(t, *sess.Config.Region, "eu-west-1")
 	assert.Nil(t, sess.Config.Endpoint)
@@ -118,12 +202,13 @@ func TestGetS3CrossRegionCapableSession_regionFromHead_noConfigOverrides(t *test
 }
 
 func TestGetS3CrossRegionCapableSession_noRegionFromHead_noConfigOverrides(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	identityMock := &identityMocks.IAgentIdentity{}
 	identityMock.On("Region").Return("cn-north-1", nil)
 
-	contextMock := new(context.Mock)
+	contextMock := new(contextmocks.Mock)
 	contextMock.On("Identity").Return(identityMock)
-	contextMock.On("Log").Return(log.NewMockLog())
+	contextMock.On("Log").Return(logmocks.NewMockLog())
 	contextMock.On("AppConfig").Return(appconfig.DefaultConfig())
 
 	setupMocksForGetS3CrossRegionCapableSession("cn-north-1", "bucket-1", "")
@@ -138,15 +223,16 @@ func TestGetS3CrossRegionCapableSession_noRegionFromHead_noConfigOverrides(t *te
 }
 
 func TestGetS3CrossRegionCapableSession_regionFromHead_withConfigOverrides(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	appConfig := appconfig.DefaultConfig()
 	appConfig.S3.Endpoint = "https://custom.endpoint.com"
 
 	identityMock := &identityMocks.IAgentIdentity{}
 	identityMock.On("Region").Return("us-east-1", nil)
 
-	contextMock := new(context.Mock)
+	contextMock := new(contextmocks.Mock)
 	contextMock.On("Identity").Return(identityMock)
-	contextMock.On("Log").Return(log.NewMockLog())
+	contextMock.On("Log").Return(logmocks.NewMockLog())
 	contextMock.On("AppConfig").Return(appConfig)
 
 	setupMocksForGetS3CrossRegionCapableSession("us-east-1", "bucket-1", "eu-west-1")
@@ -161,15 +247,16 @@ func TestGetS3CrossRegionCapableSession_regionFromHead_withConfigOverrides(t *te
 }
 
 func TestGetS3CrossRegionCapableSession_noRegionFromHead_withConfigOverrides(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	appConfig := appconfig.DefaultConfig()
 	appConfig.S3.Endpoint = "https://custom.endpoint.com.cn"
 
 	identityMock := &identityMocks.IAgentIdentity{}
 	identityMock.On("Region").Return("cn-north-1", nil)
 
-	contextMock := new(context.Mock)
+	contextMock := new(contextmocks.Mock)
 	contextMock.On("Identity").Return(identityMock)
-	contextMock.On("Log").Return(log.NewMockLog())
+	contextMock.On("Log").Return(logmocks.NewMockLog())
 	contextMock.On("AppConfig").Return(appConfig)
 
 	setupMocksForGetS3CrossRegionCapableSession("cn-north-1", "bucket-1", "")
@@ -184,8 +271,9 @@ func TestGetS3CrossRegionCapableSession_noRegionFromHead_withConfigOverrides(t *
 }
 
 func setupMocksForGetS3CrossRegionCapableSession(instanceRegion, bucketName, headBucketResponse string) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	setupMockHeadBucketResponse(bucketName, instanceRegion, headBucketResponse)
-	makeAwsConfig = func(context context.T, region string) *aws.Config {
+	makeAwsConfig = func(context context.T, service, region string) *aws.Config {
 		result := aws.NewConfig()
 		result.Region = aws.String(region)
 		result.Credentials = credentials.NewCredentials(&mockCredentialsProvider{})
@@ -194,16 +282,17 @@ func setupMocksForGetS3CrossRegionCapableSession(instanceRegion, bucketName, hea
 }
 
 func setupMockHeadBucketResponse(bucketName, instanceRegion, headBucketResponse string) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	s3Endpoint := "s3." + instanceRegion + ".amazonaws.com"
 	s3FallbackEndpoint := "s3.amazonaws.com"
 	if strings.HasPrefix(instanceRegion, "cn-") {
 		s3Endpoint += ".cn"
 		s3FallbackEndpoint = "s3.cn-north-1.amazonaws.com.cn"
 	}
-	setS3Endpoint(instanceRegion, s3Endpoint)
+	setS3Endpoint(instanceRegion, s3Endpoint, nil)
 	setS3FallbackEndpoint(instanceRegion, s3FallbackEndpoint)
 
-	getHttpProvider = func(log.T) HttpProvider {
+	getHttpProvider = func(log.T, appconfig.SsmagentConfig) HttpProvider {
 		provider := &MockedHttpProvider{}
 		resp := &http.Response{
 			Header: http.Header{},
@@ -219,13 +308,14 @@ func setupMockHeadBucketResponse(bucketName, instanceRegion, headBucketResponse
 }
 
 func TestRedirect_RedirectResponse_RetryWithCorrectRegion(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	appConfig := appconfig.DefaultConfig()
 	identityMock := &identityMocks.IAgentIdentity{}
 	identityMock.On("Region").Return("cn-northwest-1", nil)
 
-	contextMock := new(context.Mock)
+	contextMock := new(contextmocks.Mock)
 	contextMock.On("Identity").Return(identityMock)
-	contextMock.On("Log").Return(log.NewMockLog())
+	contextMock.On("Log").Return(logmocks.NewMockLog())
 	contextMock.On("AppConfig").Return(appConfig)
 
 	setupMocksForGetS3CrossRegionCapableSession("cn-northwest-1", "bucket-1", "")
@@ -279,8 +369,9 @@ func TestRedirect_RedirectResponse_RetryWithCorrectRegion(t *testing.T) {
 }
 
 func TestRedirect_BadSigningRegionResponse_RetryWithCorrectRegion(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	setupMocksForGetS3CrossRegionCapableSession("us-east-1", "bucket-1", "")
-	sess, err := GetS3CrossRegionCapableSession(context.NewMockDefault(), "bucket-1")
+	sess, err := GetS3CrossRegionCapableSession(contextmocks.NewMockDefault(), "bucket-1")
 	assert.Nil(t, err)
 
 	trans, transTypeOk := sess.Config.HTTPClient.Transport.(*s3BucketRegionHeaderCapturingTransport)
@@ -333,12 +424,13 @@ func TestRedirect_BadSigningRegionResponse_RetryWithCorrectRegion(t *testing.T)
 }
 
 func TestRedirect_CachedBucketRegion_FirstRequestGoesToCorrectRegion(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	// The correct region for the bucket is already cached.  The first
 	// attempt should go to the correct region.
 	getBucketRegionMap().Put("bucket-1", "cn-north-1")
 
 	setupMocksForGetS3CrossRegionCapableSession("cn-northwest-1", "bucket-1", "")
-	sess, err := GetS3CrossRegionCapableSession(context.NewMockDefault(), "bucket-1")
+	sess, err := GetS3CrossRegionCapableSession(contextmocks.NewMockDefault(), "bucket-1")
 	assert.Nil(t, err)
 
 	trans, transTypeOk := sess.Config.HTTPClient.Transport.(*s3BucketRegionHeaderCapturingTransport)
@@ -459,7 +551,7 @@ func validationHandlerTestCase(t *testing.T, bucketName, oldRegion, newRegion st
 	getBucketRegionMap().Put(bucketName, newRegion)
 
 	sess := session.New(config)
-	sess.Handlers.Validate.PushBackNamed(makeS3RegionCorrectingValidateHandler(log.NewMockLog()))
+	sess.Handlers.Validate.PushBackNamed(makeS3RegionCorrectingValidateHandler(logmocks.NewMockLog()))
 	svc := s3.New(sess)
 
 	request := svc.NewRequest(op, input, output)
@@ -498,7 +590,7 @@ func retryHandlerTestCase(t *testing.T, bucketName, oldRegion, newRegion string,
 	}
 
 	sess := session.New(config)
-	sess.Handlers.Retry.PushFrontNamed(makeS3RegionCorrectingRetryHandler(log.NewMockLog()))
+	sess.Handlers.Retry.PushFrontNamed(makeS3RegionCorrectingRetryHandler(logmocks.NewMockLog()))
 	svc := s3.New(sess)
 
 	request := svc.NewRequest(op, input, output)
@@ -533,6 +625,7 @@ func retryHandlerTestCase(t *testing.T, bucketName, oldRegion, newRegion string,
 }
 
 func TestValidateHandler_EndpointLookupFailure_NoChangeToRequest(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	// bucket-1 somehow got mapped to an unknown region
 	getBucketRegionMap().Put("bucket-1", "unknown-region-1")
 	config := &aws.Config{
@@ -561,7 +654,7 @@ func TestValidateHandler_EndpointLookupFailure_NoChangeToRequest(t *testing.T) {
 	svc := s3.New(sess)
 	request := svc.NewRequest(op, input, output)
 
-	handler := makeS3RegionCorrectingValidateHandler(log.NewMockLog())
+	handler := makeS3RegionCorrectingValidateHandler(logmocks.NewMockLog())
 	handler.Fn(request)
 
 	assert.Equal(t, "us-east-1", *request.Config.Region)
@@ -571,6 +664,7 @@ func TestValidateHandler_EndpointLookupFailure_NoChangeToRequest(t *testing.T) {
 }
 
 func TestRetryHandler_EndpointLookupFailure_NoChangeToRequest(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	// bucket-1 somehow got mapped to an unknown region
 	getBucketRegionMap().Put("bucket-1", "unknown-region-1")
 	config := &aws.Config{
@@ -602,7 +696,7 @@ func TestRetryHandler_EndpointLookupFailure_NoChangeToRequest(t *testing.T) {
 		StatusCode: 301,
 	}
 
-	handler := makeS3RegionCorrectingRetryHandler(log.NewMockLog())
+	handler := makeS3RegionCorrectingRetryHandler(logmocks.NewMockLog())
 	handler.Fn(request)
 
 	assert.Equal(t, "us-east-1", *request.Config.Region)
@@ -612,6 +706,7 @@ func TestRetryHandler_EndpointLookupFailure_NoChangeToRequest(t *testing.T) {
 }
 
 func TestFixupRequest_NoHttpRequestUrl_NoCustomEndpoint_SetsRegionAndEndpoint(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	request := &request.Request{
 		Config: aws.Config{
 			Region: aws.String("us-east-1"),
@@ -619,13 +714,14 @@ func TestFixupRequest_NoHttpRequestUrl_NoCustomEndpoint_SetsRegionAndEndpoint(t
 		ClientInfo:  metadata.ClientInfo{},
 		HTTPRequest: &http.Request{},
 	}
-	fixupRequest(log.NewMockLog(), request, "eu-west-1")
+	fixupRequest(logmocks.NewMockLog(), request, "eu-west-1")
 	assert.Equal(t, "eu-west-1", *request.Config.Region)
 	assert.Nil(t, request.Config.Endpoint)
 	assert.Equal(t, "https://s3.eu-west-1.amazonaws.com", request.ClientInfo.Endpoint)
 }
 
 func TestFixupRequest_NoHttpRequestUrl_CustomEndpoint_SetsRegionAndEndpoint(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	request := &request.Request{
 		Config: aws.Config{
 			Region:   aws.String("us-east-1"),
@@ -634,13 +730,14 @@ func TestFixupRequest_NoHttpRequestUrl_CustomEndpoint_SetsRegionAndEndpoint(t *t
 		ClientInfo:  metadata.ClientInfo{},
 		HTTPRequest: &http.Request{},
 	}
-	fixupRequest(log.NewMockLog(), request, "eu-west-1")
+	fixupRequest(logmocks.NewMockLog(), request, "eu-west-1")
 	assert.Equal(t, "eu-west-1", *request.Config.Region)
 	assert.Equal(t, "https://my-custom-endpoint.com", *request.Config.Endpoint)
 	assert.Equal(t, "https://my-custom-endpoint.com", request.ClientInfo.Endpoint)
 }
 
 func TestFixupRequest_HttpRequestUrl_NoCustomEndpoint_SetsRegionAndHttpRequestUrl(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	request := &request.Request{
 		Config: aws.Config{
 			Region:           aws.String("us-east-1"),
@@ -656,7 +753,7 @@ func TestFixupRequest_HttpRequestUrl_NoCustomEndpoint_SetsRegionAndHttpRequestUr
 			},
 		},
 	}
-	fixupRequest(log.NewMockLog(), request, "eu-west-1")
+	fixupRequest(logmocks.NewMockLog(), request, "eu-west-1")
 	assert.Equal(t, "eu-west-1", *request.Config.Region)
 	assert.Equal(t, "https://s3.eu-west-1.amazonaws.com", request.HTTPRequest.URL.String())
 	assert.Nil(t, request.Config.Endpoint)
@@ -664,6 +761,7 @@ func TestFixupRequest_HttpRequestUrl_NoCustomEndpoint_SetsRegionAndHttpRequestUr
 }
 
 func TestFixupRequest_HttpRequestUrlPresent_RespectsCustomEndpoint(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	request := &request.Request{
 		Config: aws.Config{
 			Region:           aws.String("us-east-1"),
@@ -680,7 +778,7 @@ func TestFixupRequest_HttpRequestUrlPresent_RespectsCustomEndpoint(t *testing.T)
 			},
 		},
 	}
-	fixupRequest(log.NewMockLog(), request, "eu-west-1")
+	fixupRequest(logmocks.NewMockLog(), request, "eu-west-1")
 	assert.Equal(t, "eu-west-1", *request.Config.Region)
 	assert.Equal(t, "https://my-custom-endpoint.com", request.HTTPRequest.URL.String())
 	assert.Equal(t, "https://my-custom-endpoint.com", *request.Config.Endpoint)
@@ -688,6 +786,7 @@ func TestFixupRequest_HttpRequestUrlPresent_RespectsCustomEndpoint(t *testing.T)
 }
 
 func TestFixupRequest_HttpRequestUrlPresent_VirtualHostedUrlWithKey(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	request := &request.Request{
 		Config: aws.Config{
 			Region:           aws.String("us-east-1"),
@@ -704,7 +803,7 @@ func TestFixupRequest_HttpRequestUrlPresent_VirtualHostedUrlWithKey(t *testing.T
 			},
 		},
 	}
-	fixupRequest(log.NewMockLog(), request, "eu-west-1")
+	fixupRequest(logmocks.NewMockLog(), request, "eu-west-1")
 	assert.Equal(t, "eu-west-1", *request.Config.Region)
 	assert.Equal(t, "https://bucket-1.s3.eu-west-1.amazonaws.com/key", request.HTTPRequest.URL.String())
 	assert.Nil(t, request.Config.Endpoint)
@@ -712,6 +811,7 @@ func TestFixupRequest_HttpRequestUrlPresent_VirtualHostedUrlWithKey(t *testing.T
 }
 
 func TestFixupRequest_HttpRequestUrlPresent_PathStyleUrlWithKey(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	request := &request.Request{
 		Config: aws.Config{
 			Region:           aws.String("us-east-1"),
@@ -728,7 +828,7 @@ func TestFixupRequest_HttpRequestUrlPresent_PathStyleUrlWithKey(t *testing.T) {
 			},
 		},
 	}
-	fixupRequest(log.NewMockLog(), request, "eu-west-1")
+	fixupRequest(logmocks.NewMockLog(), request, "eu-west-1")
 	assert.Equal(t, "eu-west-1", *request.Config.Region)
 	assert.Equal(t, "https://s3.eu-west-1.amazonaws.com/bucket-1/key", request.HTTPRequest.URL.String())
 	assert.Nil(t, request.Config.Endpoint)
@@ -736,12 +836,13 @@ func TestFixupRequest_HttpRequestUrlPresent_PathStyleUrlWithKey(t *testing.T) {
 }
 
 func TestNewS3BucketRegionHeaderCapturingTransport(t *testing.T) {
-	transport := newS3BucketRegionHeaderCapturingTransport(log.NewMockLog())
+	transport := newS3BucketRegionHeaderCapturingTransport(logmocks.NewMockLog(), appconfig.SsmagentConfig{})
 	_, goodType := transport.delegate.(*http.Transport)
 	assert.True(t, goodType)
 }
 
 func TestRoundTrip_bucketRegionHeaderPresent(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	requestUrl := "https://test-bucket.s3.cn-northwest-1.amazonaws.com.cn/a/b"
 	request := makeRequest("GET", requestUrl)
 
@@ -768,6 +869,7 @@ func TestRoundTrip_bucketRegionHeaderPresent(t *testing.T) {
 }
 
 func TestRoundTrip_bucketRegionInErrorResponseBody(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	requestUrl := "https://test-bucket.s3.cn-northwest-1.amazonaws.com.cn/a/b"
 	request := makeRequest("GET", requestUrl)
 
@@ -792,6 +894,7 @@ func TestRoundTrip_bucketRegionInErrorResponseBody(t *testing.T) {
 }
 
 func TestRoundTrip_endpointInErrorResponseBody(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	requestUrl := "https://test-bucket.s3.cn-northwest-1.amazonaws.com.cn/a/b"
 	request := makeRequest("GET", requestUrl)
 
@@ -816,6 +919,7 @@ func TestRoundTrip_endpointInErrorResponseBody(t *testing.T) {
 }
 
 func TestRoundTrip_bucketRegionNotPresent(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	requestUrl := "https://test-bucket.s3.cn-north-1.amazonaws.com.cn/a/b"
 	request := makeRequest("GET", requestUrl)
 	response := makeResponse(200, http.Header{}, "Success")
@@ -836,6 +940,7 @@ func TestRoundTrip_bucketRegionNotPresent(t *testing.T) {
 }
 
 func TestRoundTrip_error(t *testing.T) {
+	setBucketRegionFromSignedHeadBucketRequest("")
 	requestUrl := "https://test-bucket.s3.cn-north-1.amazonaws.com.cn/a/b"
 	request := makeRequest("GET", requestUrl)
 	delegate := newMockTransport()
@@ -878,28 +983,38 @@ func TestBucketRegionCache_keepsNMostRecentItems(t *testing.T) {
 func newS3BucketRegionHeaderCapturingTransportForTest(delegate http.RoundTripper) *s3BucketRegionHeaderCapturingTransport {
 	return &s3BucketRegionHeaderCapturingTransport{
 		delegate: delegate,
-		logger:   log.NewMockLog(),
+		logger:   logmocks.NewMockLog(),
 	}
 }
 
+type mockTransportResponse struct {
+	resp *http.Response
+	err  error
+}
+
 // A mock Transport implementation with a map of hard-coded responses
 // for a set of URLs.
 type mockTransport struct {
-	urlToResponseAndError map[string]*http.Response
+	urlToResponseAndError map[string]mockTransportResponse
 	requestURLsReceived   []string
 }
 
 // Create a new mockTransport with an empty response map
 func newMockTransport() *mockTransport {
 	return &mockTransport{
-		urlToResponseAndError: make(map[string]*http.Response),
+		urlToResponseAndError: make(map[string]mockTransportResponse),
 		requestURLsReceived:   make([]string, 0),
 	}
 }
 
 // Register a mock response for the specified url
 func (t *mockTransport) AddResponse(url string, response *http.Response) {
-	t.urlToResponseAndError[url] = response
+	t.urlToResponseAndError[url] = mockTransportResponse{response, nil}
+}
+
+// Register a transport error for the specified url
+func (t *mockTransport) AddTransportError(url string, err error) {
+	t.urlToResponseAndError[url] = mockTransportResponse{nil, err}
 }
 
 // Mock RoundTrip implementation.  If the request is for a URL that is in
@@ -908,7 +1023,7 @@ func (t *mockTransport) AddResponse(url string, response *http.Response) {
 func (t *mockTransport) RoundTrip(request *http.Request) (*http.Response, error) {
 	t.requestURLsReceived = append(t.requestURLsReceived, request.URL.String())
 	if response, ok := t.urlToResponseAndError[request.URL.String()]; ok {
-		return response, nil
+		return response.resp, response.err
 	}
 	return nil, fmt.Errorf("ERROR")
 }
@@ -990,19 +1105,19 @@ func makeAuthorizationHeaderMalformedErrorResponse(wrongRegion, expRegion string
 
 func TestExtractRegionFromBody_ErrorXmlWithRegion(t *testing.T) {
 	bodyContents := makeAuthorizationHeaderMalformedErrorResponse("us-east-1", "eu-west-1")
-	transport := newS3BucketRegionHeaderCapturingTransport(log.NewMockLog())
+	transport := newS3BucketRegionHeaderCapturingTransport(logmocks.NewMockLog(), appconfig.SsmagentConfig{})
 	assert.Equal(t, "eu-west-1", transport.extractRegionFromBody([]byte(bodyContents)))
 }
 
 func TestExtractRegionFromBody_ErrorXmlWithEndpoint(t *testing.T) {
 	bodyContents := makeRedirectResponseBodyText("bucket-1.s3.cn-north-1.amazonaws.com.cn", "cn-north-1")
-	transport := newS3BucketRegionHeaderCapturingTransport(log.NewMockLog())
+	transport := newS3BucketRegionHeaderCapturingTransport(logmocks.NewMockLog(), appconfig.SsmagentConfig{})
 	assert.Equal(t, "cn-north-1", transport.extractRegionFromBody([]byte(bodyContents)))
 }
 
 func TestExtractRegionFromBody_ErrorXmlWithEndpoint_PathStyleEndpointUrl(t *testing.T) {
 	bodyContents := makeRedirectResponseBodyText("s3.cn-north-1.amazonaws.com.cn/bucket-1", "cn-north-1")
-	transport := newS3BucketRegionHeaderCapturingTransport(log.NewMockLog())
+	transport := newS3BucketRegionHeaderCapturingTransport(logmocks.NewMockLog(), appconfig.SsmagentConfig{})
 	assert.Equal(t, "cn-north-1", transport.extractRegionFromBody([]byte(bodyContents)))
 }
 
@@ -1085,7 +1200,7 @@ func doGetResponseBodyTest(t *testing.T, mockResponses []mockReaderResponse, exp
 	response := &http.Response{
 		Body: body,
 	}
-	transport := newS3BucketRegionHeaderCapturingTransport(log.NewMockLog())
+	transport := newS3BucketRegionHeaderCapturingTransport(logmocks.NewMockLog(), appconfig.SsmagentConfig{})
 	actualBody, actualErr := transport.getResponseBody(response)
 	assert.Equal(t, expResult, actualBody)
 	assert.Equal(t, expErr, actualErr)
