@@ -21,6 +21,7 @@ import (
 	"math/rand"
 	"os"
 	"path/filepath"
+	"slices"
 	"strings"
 	"sync"
 	"time"
@@ -100,6 +101,7 @@ func NewUpdater(context context.T, info updateinfo.T, updateUtilRef *updateutil.
 			clean:               cleanAgentArtifacts,
 			runTests:            testerPkg.StartTests,
 			finalize:            finalizeUpdateAndSendReply,
+			reportMetric:        reportIntermediateMetric,
 		},
 	}
 
@@ -369,10 +371,7 @@ func validateUpdateParam(mgr *updateManager, logger log.T, updateDetail *UpdateD
 		updateDetail.RequiresUninstall = true
 		logger.Infof("Source version is higher than target version, will require a downgrade")
 
-		// TODO: if updateDetail.TargetResolver != updateconstants.TargetVersionCustomerDefined { override allowDowngrade
-		//        - If latest active version is < current version, current version has been deprecated and there is no newer version
-
-		if !updateDetail.AllowDowngrade {
+		if !updateDetail.AllowDowngrade && !allowDowngradeForVersionNotActive(mgr, logger, updateDetail) {
 			logger.Warnf("Downgrade is not enabled, please enable downgrade to perform this update")
 			return mgr.failed(updateDetail, logger, updateconstants.ErrorAttemptToDowngrade, fmt.Sprintf("Updating %v to an older version %v, please enable allow downgrade to proceed", updateDetail.SourceVersion, updateDetail.TargetVersion), true)
 		}
@@ -413,6 +412,22 @@ func validateUpdateParam(mgr *updateManager, logger log.T, updateDetail *UpdateD
 	return mgr.populateUrlHash(mgr, logger, updateDetail)
 }
 
+// Allow rollback if current version installed is not active
+// And that customer are not manually specifying a version.
+func allowDowngradeForVersionNotActive(mgr *updateManager, logger log.T, updateDetail *UpdateDetail) (allowed bool) {
+	isSourceVersionActive, err := updateDetail.Manifest.IsVersionActive(appconfig.DefaultAgentName, updateDetail.SourceVersion)
+	if err != nil {
+		// If we cannot read manifest, err on the safe side and do not change behavior
+		logger.Errorf("Unable to read manifest file to verify active version: ", err)
+		return
+	}
+	if updateDetail.TargetResolver != updateconstants.TargetVersionCustomerDefined && !isSourceVersionActive {
+		logger.Infof("Current version %s is not active, allow downgrade", updateDetail.SourceVersion)
+		allowed = true
+	}
+	return
+}
+
 // populateUrlHash continues initializing after self update has been handled
 func populateUrlHash(mgr *updateManager, logger log.T, updateDetail *UpdateDetail) (err error) {
 	logger.Infof("Attempting to get download url and artifact hashes from manifest")
@@ -501,10 +516,23 @@ func proceedUpdate(mgr *updateManager, log log.T, updateDetail *UpdateDetail) (e
 				updateDetail.PackageName,
 				updateDetail.SourceVersion)
 			mgr.subStatus = updateconstants.Downgrade
+
+			// Command never executes, no need to rollback
+			if exitCode == updateconstants.ExitCodeErrorPrepareUpdateCommand {
+				errorCode := updateconstants.ErrorUninstallFailed + updateconstants.ErrorCode(updateconstants.ErrorPrepareUpdateCommandSuffix)
+				return mgr.failed(updateDetail, log, errorCode, message, true)
+			}
+
 			if exitCode == updateconstants.ExitCodeUnsupportedPlatform {
 				return mgr.failed(updateDetail, log, updateconstants.ErrorUnsupportedServiceManager, message, true)
 			}
-			return mgr.failed(updateDetail, log, updateconstants.ErrorUninstallFailed, message, true)
+
+			if slices.Contains(updateconstants.ExitCodesUpdateErrorUsingPkgMgr, exitCode) {
+				updateDetail.AppendError(log, message)
+				mgr.reportMetric(mgr, updateDetail, insertPkgMgrErrorCode(updateconstants.ErrorUninstallFailed, exitCode))
+			} else {
+				return mgr.failed(updateDetail, log, updateconstants.ErrorUninstallFailed, message, true)
+			}
 		}
 	}
 
@@ -523,12 +551,28 @@ func proceedUpdate(mgr *updateManager, log log.T, updateDetail *UpdateDetail) (e
 			updateDetail.TargetVersion)
 		updateDetail.AppendError(log, message)
 
+		// Command never executes, no need to rollback
+		if exitCode == updateconstants.ExitCodeErrorPrepareUpdateCommand {
+			errorCode := updateconstants.ErrorInstallFailed + updateconstants.ErrorCode(updateconstants.ErrorPrepareUpdateCommandSuffix)
+			return mgr.failed(updateDetail, log, errorCode, message, true)
+		}
+
 		if exitCode == updateconstants.ExitCodeUnsupportedPlatform {
 			return mgr.failed(updateDetail, log, updateconstants.ErrorUnsupportedServiceManager, message, true)
 		}
+
 		if exitCode == updateconstants.ExitCodeUpdateFailedDueToSnapd {
 			return mgr.failed(updateDetail, log, updateconstants.ErrorInstallFailureDueToSnapd, message, true)
 		}
+
+		if exitCode == updateconstants.ExitCodeInstallFailedDueToSigningIssue {
+			mgr.reportMetric(mgr, updateDetail, updateconstants.ErrorInstallFailedDueToSigningIssue)
+		}
+
+		if slices.Contains(updateconstants.ExitCodesUpdateErrorUsingPkgMgr, exitCode) {
+			mgr.reportMetric(mgr, updateDetail, insertPkgMgrErrorCode(updateconstants.ErrorInstallFailed, exitCode))
+		}
+
 		updateDetail.AppendInfo(
 			log,
 			"Initiating rollback %v to %v",
@@ -620,12 +664,23 @@ func rollbackInstallation(mgr *updateManager, log log.T, updateDetail *UpdateDet
 			updateDetail.PackageName,
 			updateDetail.TargetVersion)
 
+		if exitCode == updateconstants.ExitCodeErrorPrepareUpdateCommand {
+			errorCode := updateconstants.ErrorUninstallFailed + updateconstants.ErrorCode(updateconstants.ErrorPrepareUpdateCommandSuffix)
+			return mgr.failed(updateDetail, log, errorCode, message, false)
+		}
+
 		// this case is not possible at all as we would have caught it in the earlier uninstall/install
 		// if this happens, something else is wrong so it is better to have this code for differentiation
 		if exitCode == updateconstants.ExitCodeUnsupportedPlatform {
-			return mgr.failed(updateDetail, log, updateconstants.ErrorUnsupportedServiceManager, message, true)
+			return mgr.failed(updateDetail, log, updateconstants.ErrorUnsupportedServiceManager, message, false)
+		}
+
+		if slices.Contains(updateconstants.ExitCodesUpdateErrorUsingPkgMgr, exitCode) {
+			updateDetail.AppendError(log, message)
+			mgr.reportMetric(mgr, updateDetail, insertPkgMgrErrorCode(updateconstants.ErrorUninstallFailed, exitCode))
+		} else {
+			return mgr.failed(updateDetail, log, updateconstants.ErrorUninstallFailed, message, false)
 		}
-		return mgr.failed(updateDetail, log, updateconstants.ErrorUninstallFailed, message, false)
 	}
 
 	if exitCode, err := mgr.install(mgr, log, updateDetail.SourceVersion, updateDetail); err != nil {
@@ -636,12 +691,22 @@ func rollbackInstallation(mgr *updateManager, log log.T, updateDetail *UpdateDet
 			updateDetail.PackageName,
 			updateDetail.SourceVersion)
 
+		if exitCode == updateconstants.ExitCodeErrorPrepareUpdateCommand {
+			errorCode := updateconstants.ErrorInstallFailed + updateconstants.ErrorCode(updateconstants.ErrorPrepareUpdateCommandSuffix)
+			return mgr.failed(updateDetail, log, errorCode, message, false)
+		}
+
 		// this case is not possible at all as we would have caught it in the earlier uninstall/install
 		// if this happens, something else is wrong and it is better to have this code for differentiation
 		if exitCode == updateconstants.ExitCodeUnsupportedPlatform {
-			return mgr.failed(updateDetail, log, updateconstants.ErrorUnsupportedServiceManager, message, true)
+			return mgr.failed(updateDetail, log, updateconstants.ErrorUnsupportedServiceManager, message, false)
 		}
-		return mgr.failed(updateDetail, log, updateconstants.ErrorInstallFailed, message, false)
+
+		if exitCode == updateconstants.ExitCodeInstallFailedDueToSigningIssue {
+			return mgr.failed(updateDetail, log, updateconstants.ErrorInstallFailedDueToSigningIssue, message, false)
+		}
+
+		return mgr.failed(updateDetail, log, insertPkgMgrErrorCode(updateconstants.ErrorInstallFailed, exitCode), message, false)
 	}
 
 	if err = mgr.inProgress(updateDetail, log, RolledBack); err != nil {
@@ -732,16 +797,25 @@ func installAgent(mgr *updateManager, log log.T, version string, updateDetail *U
 	}
 	for retryCounter := 1; retryCounter <= installRetryCount; retryCounter++ {
 		updateExecutionTimeoutIfNeeded(retryCounter, defaultTimeOut, mgr.util)
-		if retryCounter == installRetryCount && strings.Contains(mgr.Info.GetInstallScriptName(), "snap") {
-			log.Info("execute command and fetch error output for agent install using snap")
-			var errBytes *bytes.Buffer
-			_, exitCode, _, errBytes, err = mgr.util.ExecCommandWithOutput(input)
-			if err != nil && errBytes != nil && errBytes.Len() != 0 {
-				if strings.Contains(errBytes.String(), "snap \"amazon-ssm-agent\" has running apps") {
-					log.Errorf("command failure for agent installed using snap: %v", err)
-					return updateconstants.ExitCodeUpdateFailedDueToSnapd, err
+		if retryCounter == installRetryCount {
+			log.Info("execute command and fetch error output for agent install")
+			var outBytes, errBytes *bytes.Buffer
+			_, exitCode, outBytes, errBytes, err = mgr.util.ExecCommandWithOutput(input)
+
+			if strings.Contains(mgr.Info.GetInstallScriptName(), "snap") {
+				if err != nil && errBytes != nil && errBytes.Len() != 0 {
+					if strings.Contains(errBytes.String(), "snap \"amazon-ssm-agent\" has running apps") {
+						log.Errorf("command failure for agent installed using snap: %v", err)
+						return updateconstants.ExitCodeUpdateFailedDueToSnapd, err
+					}
 				}
 			}
+
+			if outBytes != nil && outBytes.Len() != 0 && strings.Contains(outBytes.String(), "does not verify: no digest") {
+				log.Errorf("command failure for agent installed with no header: %v", err)
+				return updateconstants.ExitCodeInstallFailedDueToSigningIssue, err
+			}
+
 		} else {
 			_, exitCode, err = mgr.util.ExeCommand(input)
 		}
@@ -752,7 +826,7 @@ func installAgent(mgr *updateManager, log log.T, version string, updateDetail *U
 			backOff := getNextBackOff(retryCounter)
 
 			// Increase backoff by 30 seconds if package manager fails
-			if exitCode == updateconstants.ExitCodeUpdateUsingPkgMgr {
+			if slices.Contains(updateconstants.ExitCodesUpdateErrorUsingPkgMgr, exitCode) {
 				backOff += time.Duration(30) * time.Second // 30 seconds
 			}
 
@@ -891,3 +965,20 @@ func downloadAndUnzipArtifact(
 
 	return nil
 }
+
+// insertPkgMgrErrorCode inserts package manager error code suffix when applies
+func insertPkgMgrErrorCode(errorCode updateconstants.ErrorCode, exitCode updateconstants.UpdateScriptExitCode) (result updateconstants.ErrorCode) {
+	switch exitCode {
+	default:
+		result = errorCode
+	case updateconstants.ExitCodeUpdateErrorUsingYumAndRpm:
+		result = errorCode + updateconstants.ErrorCode(updateconstants.ErrorUsingYumAndRpmSuffix)
+	case updateconstants.ExitCodeUpdateErrorUsingDpkg:
+		result = errorCode + updateconstants.ErrorCode(updateconstants.ErrorUsingDpkgSuffix)
+	case updateconstants.ExitCodeUpdateErrorUsingSnap:
+		result = errorCode + updateconstants.ErrorCode(updateconstants.ErrorUsingSnapSuffix)
+	case updateconstants.ExitCodeUpdateErrorUsingPkgMgrLegacy:
+		result = errorCode + updateconstants.ErrorCode(updateconstants.ErrorUsingPkgMgrLegacySuffix)
+	}
+	return
+}
