@@ -11,16 +11,16 @@
 // either express or implied. See the License for the specific language governing
 // permissions and limitations under the License.
 
+//go:build windows
 // +build windows
 
 // Package main represents the entry point of the ssm agent updater.
 package main
 
 import (
-	"github.com/aws/amazon-ssm-agent/agent/appconfig"
+	logger "github.com/aws/amazon-ssm-agent/agent/log"
 )
 
-// resolveUpdateRoot returns the platform specific path to update artifacts
-func resolveUpdateRoot(sourceVersion string) (string, error) {
-	return appconfig.UpdaterArtifactsRoot, nil
+func updateSSMUserShellProperties(log logger.T) {
+	return
 }
