@@ -16,9 +16,11 @@
 
 package darwinec2detector
 
+import "github.com/aws/amazon-ssm-agent/agent/log"
+
 type darwinEc2Detector struct{}
 
-func (*darwinEc2Detector) IsEc2() bool {
+func (*darwinEc2Detector) IsEc2(_ log.T) bool {
 	// Darwin is only supported in EC2, assume we are on EC2
 	return true
 }
